@@ -31,6 +31,8 @@
 #include "resources/skeletonresource.h"
 #include <ui/newcoursedialog.h>
 #include "settings.h"
+#include "liblearnerprofile/src/profilemanager.h"
+#include "liblearnerprofile/src/learninggoal.h"
 
 #include <QIODevice>
 #include <QFile>
@@ -53,6 +55,9 @@ ResourceManager::ResourceManager(QObject *parent)
 
 void ResourceManager::loadCourseResources()
 {
+    // reload config, could be changed in dialogs
+    Settings::self()->readConfig();
+
     // register skeleton resources
     QDir skeletonRepository = QDir(Settings::courseRepositoryPath());
     skeletonRepository.setFilter(QDir::Files | QDir::Hidden);
@@ -113,10 +118,10 @@ void ResourceManager::loadCourseResources()
         QString directory = courseFile.directory().section('/', -1);
         addCourse(courseFile);
     }
-    QStringList skeletonFiles = KGlobal::dirs()->findAllResources("appdata",QString("skeletons/*.xml"));
-    foreach (const QString &file, skeletonFiles) {
-        addSkeleton(KUrl::fromLocalFile(file));
-    }
+
+    //TODO this signal should only be emitted when repository was added/removed
+    // yet the call to this method is very seldom and emitting it too often is not that harmful
+    emit repositoryChanged();
 }
 
 void ResourceManager::loadLanguageResources()
@@ -129,6 +134,17 @@ void ResourceManager::loadLanguageResources()
     }
 }
 
+void ResourceManager::registerLearningGoals(LearnerProfile::ProfileManager *profileManger)
+{
+    foreach (LanguageResource *languageResource, languageResources()) {
+        profileManger->registerGoal(
+            LearnerProfile::LearningGoal::Language,
+            languageResource->language()->id(),
+            languageResource->language()->i18nTitle()
+            );
+    }
+}
+
 void ResourceManager::addLanguage(const KUrl &languageFile)
 {
     if (m_loadedResources.contains(languageFile.toLocalFile())) {
@@ -156,10 +172,28 @@ QList< LanguageResource* > ResourceManager::languageResources() const
 
 Language * ResourceManager::language(int index) const
 {
-    Q_ASSERT (index >= 0 && index < m_languageResources.count());
+    Q_ASSERT(index >= 0 && index < m_languageResources.count());
     return m_languageResources.at(index)->language();
 }
 
+Language * ResourceManager::language(LearnerProfile::LearningGoal *learningGoal) const
+{
+    if (!learningGoal) {
+        return 0;
+    }
+    if (learningGoal->category() != LearnerProfile::LearningGoal::Language) {
+        kError() << "Cannot translate non-language learning goal to language";
+        return 0;
+    }
+    foreach (LanguageResource *resource, m_languageResources) {
+        if (resource->identifier() == learningGoal->identifier()) {
+            return resource->language();
+        }
+    }
+    kError() << "No language registered with identifier " << learningGoal->identifier() << ": aborting";
+    return 0;
+}
+
 QList< CourseResource* > ResourceManager::courseResources(Language *language)
 {
     Q_ASSERT(language);
@@ -197,6 +231,7 @@ void ResourceManager::reloadCourseOrSkeleton(Course *courseOrSkeleton)
         //TODO better add a check if this is contained in the course list
         // to catch possible errors
         KUrl file = courseOrSkeleton->file();
+        m_loadedResources.removeOne(courseOrSkeleton->file().toLocalFile());
         removeCourse(courseOrSkeleton);
         addCourse(file);
     } else {
@@ -322,18 +357,23 @@ void ResourceManager::removeCourse(Course *course)
         if (m_courseResources[course->language()->id()].at(index)->course() == course) {
             emit courseResourceAboutToBeRemoved(index);
             m_courseResources[course->language()->id()].removeAt(index);
-            emit courseResourceRemoved();
             course->deleteLater();
             return;
         }
     }
 }
 
-void ResourceManager::newCourseDialog()
+void ResourceManager::newCourseDialog(Language *language)
 {
     QPointer<NewCourseDialog> dialog = new NewCourseDialog(this);
-    if (dialog->exec() == QDialog::Accepted ) {
+    if (language != 0) {
+        dialog->setLanguage(language);
+    }
+    if (dialog->exec() == QDialog::Accepted) {
+        CourseResource *tempCourse = dialog->courseResource();
+        tempCourse->setContributorResource(true);
         addCourseResource(dialog->courseResource());
+        emit languageCoursesChanged();
     }
 }
 
